# estore
Meta package for estore packages

## Installing

If you are after the client:

```bash
pip install estore[client]
```

If you need server only, simply run:

```bash
pip install estore[server]
```
